==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <location filename="../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Policykit információ</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Már fut egy más hitelesítő.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Hitelesítés sikertelen</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Hitelesítés valami miatt sikertelen</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Policykit hiba</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Hitelesítés kell</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Policykit információ</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Már fut egy más hitelesítő.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Hitelesítés sikertelen</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Hitelesítés valami miatt sikertelen</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Policykit hiba</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Hitelesítés kell</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
</TS>
